#### R-script belonging to the article "Diversity bears fruit: Evaluating the economic potential of undervalued fruits for an agroecological restoration approach in the Peruvian Amazon"
# with this script revenue of individual NUS trees, and revenue, costs and income of an agroforestry system in which several high-potential NUS are combined
# The script is divided in 3 parts: 1.Projecting single species revenue over time, 2.Projecting profit over time for a mixed NUS agroforestry system, 3.Projecting profit over time for a mixed NUS agroforestry system, RANDOMIZED 
# Running the script results in the creation of figures 4 and 5 of the article and several additional figures
# Before the script can be ran, the data tables that are supplied separately should be read in

# Read in data
Data1=read.csv(file="Data 1_Productivity and Prices.csv",header=T,sep=",")
Data1=read.csv("C:/Users/merel/Dropbox/SUSTAIN2/student projects/Elisabeth Lagneaux/Sustainability submission/Data 1_Productivity and Prices.csv",header=T,sep=",")
Data2=read.csv("C:/Users/merel/Dropbox/SUSTAIN2/student projects/Elisabeth Lagneaux/Sustainability submission/Data 2_Design and Months of productivity.csv",header=T,sep=",")

#### Load relevant libraries
library(boot)
library(ggplot2)
library(gridExtra)

#### Create Useful vectors that are needed later  
time=c(1:30)
fruitsorg<-levels(Data2[,"Fruit"])
fruits<- levels(as.factor(Data1[,"Fruit"]))

huasaisel<-Data1[,"Fruit"]%in%"Huasai"
aguajesel<-Data1[,"Fruit"]%in%"Aguaje"
arazasel<-Data1[,"Fruit"]%in%"Araza"
camucamusel<-Data1[,"Fruit"]%in%"Camu-camu"
coconasel<-Data1[,"Fruit"]%in%"Cocona"
copoazusel<-Data1[,"Fruit"]%in%"Copoazu"
guabasel<-Data1[,"Fruit"]%in%"Guaba"
guanabanasel<-Data1[,"Fruit"]%in%"Guanabana"
pijuayosel<-Data1[,"Fruit"]%in%"Pijuayo"
ungurahuisel<-Data1[,"Fruit"]%in%"Ungurahui"

huasaisel2<-Data2[,1]%in%"Huasai"
aguajesel2<-Data2[,1]%in%"Aguaje"
arazasel2<-Data2[,1]%in%"Araza"
camucamusel2<-Data2[,1]%in%"Camu-camu"
coconasel2<-Data2[,1]%in%"Cocona"
copoazusel2<-Data2[,1]%in%"Copoazu"
guabasel2<-Data2[,1]%in%"Guaba"
guanabanasel2<-Data2[,1]%in%"Guanabana"
pijuayosel2<-Data2[,1]%in%"Pijuayo"
ungurahuisel2<-Data2[,1]%in%"Ungurahui"

#### Projecting single species revenue over time ####

#create function including loop over all fruits
speciesincome<-array(NA,dim=c(30,3,10))
for(f in 1:10){
  fruitf<-function(x,d){
    x2<-x[d,]
    timevec<-matrix(NA,30,1)
    fruitsel<-x2[,"Fruit"]%in%fruits[f]
    meanyears<-ceiling(mean(x2[fruitsel,"Years"],na.rm=T))
    meanprod<-mean(x2[fruitsel,"Prod"],na.rm=T)
    meanprice<-mean(x2[fruitsel,"Price"],na.rm=T)
    for(y in 1:30){
      ynyear<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/4),ifelse((y-meanyears)==1,(2/4),ifelse((y-meanyears)==2,3/4,1))))
      ynyearCocona<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/2),ifelse((y-meanyears)==1,1,ifelse((y-meanyears)==2,1/2,0)))) 
      ynyearAraza<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/4),ifelse((y-meanyears)==1,(2/4),ifelse((y-meanyears)==2,3/4,ifelse((y-meanyears)==3,1,ifelse((y-meanyears)==4,3/4,1/2))))))
      if(f%in%c(1,2,4,6:10)){timevec[y,1]<-0.9*ynyear*meanprod*meanprice}
      if(f%in%c(3)){timevec[y,1]<-0.9*ynyearAraza*meanprod*meanprice}
      if(f%in%c(5)){timevec[y,1]<-0.9*ynyearCocona*meanprod*meanprice}
    }   
    return(timevec)
  }
  
  #bootstrap
  b2sp=boot(Data1,fruitf,R=10000)
  b2sp$t0
  
  #make plotable data frame from bootstrap result
  spallincome<-matrix(NA,30,3)
  colnames(spallincome)<-c("mean","min","max")
  spallincome[,1]<-b2sp$t0
  for(i in 1:30){
    spallincome[i,2]<-quantile(b2sp$t[,i],0.025,na.rm=T)
    spallincome[i,3]<-quantile(b2sp$t[,i],0.975,na.rm=T)
  }
  speciesincome[,,f]<-spallincome
}

#ggplot income
fruitcols<-c("plum","yellow2","yellow4","red4","yellow3","burlywood","brown1","green2","yellow1","purple3")
par(mfrow=c(2,5))
myplots <- vector('list', 10)
for(f in 1:10){
  message(f)
  fruitn<-fruits[f]
  fruitcol<-fruitcols[f]
  income<-speciesincome[,,f]
  income<-as.data.frame(income)
  income[,4]<-c(1:30)
  colnames(income)<-c("mean","min","max","time")
  myplots[[f]] <- local({
    f<-f
    p1<-ggplot(income,aes(x=time,y=mean))+
      geom_ribbon(fill = fruitcol,alpha=0.5,aes(x=time,ymin=min,ymax=max))+
      geom_line(alpha=0.8)+
      labs(title=fruitn,y="Revenue (PEN/tree/y)", x="Time (y)")
    print(p1)
  })}
grid.arrange(myplots[[1]],myplots[[2]],myplots[[3]],myplots[[4]],myplots[[5]],myplots[[6]],myplots[[7]],myplots[[8]],myplots[[9]],myplots[[10]], nrow = 2)

#### Projecting profit over time for a mixed NUS agroforestry system ####

#create function
incomef<-function(x,d){
  timevec<-matrix(NA,30,10)
  timevecn<-matrix(NA,30,10)
  x2<-x[d,]
  for(f in 1:10){
    fruitsel<-x2[,"Fruit"]%in%fruits[f]
    meanyears<-ceiling(mean(x2[fruitsel,"Years"],na.rm=T))
    meanprod<-mean(x2[fruitsel,"Prod"],na.rm=T)
    meanprice<-mean(x2[fruitsel,"Price"],na.rm=T)
    for(y in 1:30){
      ynyear<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/4),ifelse((y-meanyears)==1,(2/4),ifelse((y-meanyears)==2,3/4,1))))
      ynyearCocona<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/2),ifelse((y-meanyears)==1,1,ifelse((y-meanyears)==2,1/2,0)))) 
      ynyearAraza<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/4),ifelse((y-meanyears)==1,(2/4),ifelse((y-meanyears)==2,3/4,ifelse((y-meanyears)==3,1,ifelse((y-meanyears)==4,3/4,1/2))))))
      if(f%in%c(1,2,4,6:10)){timevec[y,f]<-0.9*ynyear*meanprod*meanprice}
      if(f%in%c(3)){timevec[y,f]<-0.9*ynyearAraza*meanprod*meanprice}
      if(f%in%c(5)){timevec[y,f]<-0.9*ynyearCocona*meanprod*meanprice}
      timevecn[y,f]<-timevec[y,f]*Data2[f,"Trees4ha"]
    }  
  }
  return(rowSums(timevecn))
}

#bootstrap
b2=boot(Data1,incomef,R=10000)
b2$t0

#make plotable data frame from bootstrap result
allincome<-matrix(NA,30,3)
colnames(allincome)<-c("mean","min","max")
allincome[,1]<-b2$t0
for(y in 1:30){
  allincome[y,2]<-quantile(b2$t[,y],0.025,na.rm=T)
  allincome[y,3]<-quantile(b2$t[,y],0.975,na.rm=T)
}

#ggplot income
allincome<-as.data.frame(allincome)
allincome[,"time"]<-c(1:30)
head(allincome)
prev<-ggplot(allincome,aes(x=time,y=mean))+
  geom_ribbon(fill = "palegreen3",alpha=0.5,aes(x=time,ymin=min,ymax=max))+
  geom_line()+
  labs(y="Revenue (PEN/4ha/y)", x="Time (y)")
prev

#### Cost calculation 

#create function
costf<-function(x,d){
  timeveccost<-matrix(NA,30,10)
  timeveccostn<-matrix(NA,30,10)
  for(f in 1:10){
    x2<-x[d,]
    fruitsel<-x2[,"Fruit"]%in%fruits[f]
    meanyears<-ceiling(mean(x2[fruitsel,"Years"][d],na.rm=T))
    ntrees<-Data2[f,"Trees4ha"]
    prodmonths<-Data2[f,"MonthsProdYear"]
    
    for(y in 1:30){
      ynyear01<-ifelse(y<meanyears,0,1)
      ynyear01Cocona<-ifelse((y-meanyears)%in%c(0,1,2),1,0)
      ynyear01Araza<-ifelse(y<meanyears,0,1)
      
      establishmentcost<-ifelse(y==1,10000,0)
      
      if(f%in%c(5)){costseedlings<-0}
      if(f%in%c(1:4,6:10)){costseedlings<-ifelse(y==1,ntrees*3,ifelse(y==2,ntrees*0.15*3,ifelse(y==3,ntrees*0.05*3,ntrees*0.005*3)))}
      
      if(f%in%c(1,2,4,6:10)){costharvest<-ynyear01*4*prodmonths*50}
      if(f%in%c(3)){costharvest<-ynyear01Araza*4*prodmonths*50}
      if(f%in%c(5)){costharvest<-ynyear01Cocona*4*prodmonths*50}
      
      transportcost<-200*12
      
      timeveccost[y,f]<-(establishmentcost/10)+costharvest+costseedlings+(transportcost/10)
    }  
  }
  return(rowSums(timeveccost))
}

#bootstrap
b2cost=boot(Data1,costf,R=10000)
b2cost$t0

#make plotable data frame from bootstrap result
allcost<-matrix(NA,30,3)
colnames(allcost)<-c("mean","min","max")
allcost[,1]<-b2cost$t0
for(i in 1:30){
  allcost[i,2]<-quantile(b2cost$t[,i],0.025,na.rm=T)
  allcost[i,3]<-quantile(b2cost$t[,i],0.975,na.rm=T)
}
allcost<-as.data.frame(allcost)
allcost[,"time"]<-c(1:30)

#ggplot
pcost<-ggplot(allcost,aes(x=time,y=mean))+
  geom_ribbon(fill = "blue",alpha=0.5,aes(x=time,ymin=min,ymax=max))+
  geom_line()+
  labs(y="Costs (PEN/4ha/y)", x="Time (y)")
pcost

#### Profit 
profitf<-function(x,d){incomef(x,d)-costf(x,d)}

# bootstrap
b2profit=boot(Data1,profitf,R=10000)
b2profit$t0

#make plotable data frame from bootstrap result
allprofit<-matrix(NA,30,3)
colnames(allprofit)<-c("mean","min","max")
allprofit[,1]<-b2profit$t0
for(y in 1:30){
  allprofit[y,2]<-quantile(b2profit$t[,y],0.025,na.rm=T)
  allprofit[y,3]<-quantile(b2profit$t[,y],0.975,na.rm=T)
}

#ggplot profit
allprofit<-as.data.frame(allprofit)
allprofit[,"time"]<-c(1:30)

pprof<-ggplot(allprofit,aes(x=time,y=mean))+
  geom_ribbon(fill = "palevioletred3",alpha=0.5,aes(x=time,ymin=min,ymax=max))+
  geom_line()+
  labs(y="Profit (PEN/4ha/y)", x="Time (y)")
pprof

#### Create a combined plot of revenue, costs and income
grid.arrange(prev,pcost,pprof, nrow = 1)

#### Projecting profit over time for a mixed NUS agroforestry system, RANDOMIZED  ####

#create function
incomefrandom<-function(x,d){
  ##Determine frequencies
  
  #shade givers (n=5)
  sg1<-sample(c(1:400),1)
  sg2<-ifelse(sg1==400,0,sample(c(1:(400-sg1)),1))
  sg3<-ifelse((sg1+sg2)==400,0,sample(c(1:(400-(sg1+sg2))),1))
  sg4<-ifelse((sg1+sg2+sg3)==400,0,sample(c(1:(400-(sg1+sg2+sg3))),1))
  sg5<-ifelse((sg1+sg2+sg3+sg4)==400,0,400-(sg1+sg2+sg3))
  ntreesguaba<-sg1
  ntreeshuasai<-sg2
  ntreesaguaje<-sg3
  ntreespijuayo<-sg4
  ntreesungurahui<-sg5
  
  #shade tolerant (n=2)
  st1<-sample(c(1:400),1)
  st2<-ifelse(st1==400,0,400-st1)
  ntreesaraza<-st1
  ntreescopoazu<-st2
  
  #light demanding (n=2)
  ld1<-sample(c(1:400),1)
  ld2<-ifelse(ld1==400,0,400-ld1)
  ntreescamucamu<-ld1
  ntreesguanabana<-ld2
  
  #cocona
  ntreescocona<-800
  
  ntreesmat<-matrix(NA,10,1)
  ntreesmat[1,1]<-ntreeshuasai
  ntreesmat[2,1]<-ntreesaguaje
  ntreesmat[3,1]<-ntreesaraza
  ntreesmat[4,1]<-ntreescamucamu
  ntreesmat[5,1]<-ntreescocona
  ntreesmat[6,1]<-ntreescopoazu
  ntreesmat[7,1]<-ntreesguaba
  ntreesmat[8,1]<-ntreesguanabana
  ntreesmat[9,1]<-ntreespijuayo
  ntreesmat[10,1]<-ntreesungurahui
  
  timevec<-matrix(NA,30,10)
  timevecn<-matrix(NA,30,10)
  for(f in 1:10){
    x2<-x[d,]
    fruitsel<-x2[,"Fruit"]%in%fruits[f]
    meanyears<-ceiling(mean(x2[fruitsel,"Years"],na.rm=T))
    meanprod<-mean(x2[fruitsel,"Prod"],na.rm=T)
    meanprice<-mean(x2[fruitsel,"Price"],na.rm=T)
    for(y in 1:30){
      ynyear<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/4),ifelse((y-meanyears)==1,(2/4),ifelse((y-meanyears)==2,3/4,1))))
      ynyearCocona<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/2),ifelse((y-meanyears)==1,1,ifelse((y-meanyears)==2,1/2,0)))) 
      ynyearAraza<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/4),ifelse((y-meanyears)==1,(2/4),ifelse((y-meanyears)==2,3/4,ifelse((y-meanyears)==3,1,ifelse((y-meanyears)==4,3/4,1/2))))))
      if(f%in%c(1,2,4,6:10)){timevec[y,f]<-0.9*ynyear*meanprod*meanprice}
      if(f%in%c(3)){timevec[y,f]<-0.9*ynyearAraza*meanprod*meanprice}
      if(f%in%c(5)){timevec[y,f]<-0.9*ynyearCocona*meanprod*meanprice}
      timevecn[y,f]<-timevec[y,f]*ntreesmat[f,1]
    }  
  }
  return(rowSums(timevecn))
}

#bootstrap
b2random=boot(Data1,incomefrandom,R=10000)
b2random$t0

#make plotable data frame from bootstrap result
allincomerandom<-matrix(NA,30,3)
colnames(allincomerandom)<-c("mean","min","max")
allincomerandom[,1]<-b2random$t0
for(y in 1:30){
  allincomerandom[y,2]<-quantile(b2random$t[,y],0.025,na.rm=T)
  allincomerandom[y,3]<-quantile(b2random$t[,y],0.975,na.rm=T)
}

#ggplot income
allincomerandom<-as.data.frame(allincomerandom)
allincomerandom[,"time"]<-c(1:30)
head(allincomerandom)
prevrandom<-ggplot(allincomerandom,aes(x=time,y=mean))+
  geom_ribbon(fill = "palegreen3",alpha=0.5,aes(x=time,ymin=min,ymax=max))+
  geom_line()+
  labs(y="Revenue (PEN/4ha/y)", x="Time (y)")
prevrandom

#### Cost calculations

# create function
costfrandom<-function(x,d){
  ##Determine frequencies
  
  #shade givers (n=5)
  sg1<-sample(c(1:400),1)
  sg2<-ifelse(sg1==400,0,sample(c(1:(400-sg1)),1))
  sg3<-ifelse((sg1+sg2)==400,0,sample(c(1:(400-(sg1+sg2))),1))
  sg4<-ifelse((sg1+sg2+sg3)==400,0,sample(c(1:(400-(sg1+sg2+sg3))),1))
  sg5<-ifelse((sg1+sg2+sg3+sg4)==400,0,400-(sg1+sg2+sg3))
  ntreesguaba<-sg1
  ntreeshuasai<-sg2
  ntreesaguaje<-sg3
  ntreespijuayo<-sg4
  ntreesungurahui<-sg5
  
  #shade tolerant (n=2)
  st1<-sample(c(1:400),1)
  st2<-ifelse(st1==400,0,400-st1)
  ntreesaraza<-st1
  ntreescopoazu<-st2
  
  #light demanding (n=2)
  ld1<-sample(c(1:400),1)
  ld2<-ifelse(ld1==400,0,400-ld1)
  ntreescamucamu<-ld1
  ntreesguanabana<-ld2
  
  #cocona
  ntreescocona<-800
  
  ntreesmat<-matrix(NA,10,1)
  ntreesmat[1,1]<-ntreeshuasai
  ntreesmat[2,1]<-ntreesaguaje
  ntreesmat[3,1]<-ntreesaraza
  ntreesmat[4,1]<-ntreescamucamu
  ntreesmat[5,1]<-ntreescocona
  ntreesmat[6,1]<-ntreescopoazu
  ntreesmat[7,1]<-ntreesguaba
  ntreesmat[8,1]<-ntreesguanabana
  ntreesmat[9,1]<-ntreespijuayo
  ntreesmat[10,1]<-ntreesungurahui
  
  timeveccost<-matrix(NA,30,10)
  timeveccostn<-matrix(NA,30,10)
  x2<-x[d,]
  for(f in 1:10){
    fruitsel<-x2[,"Fruit"]%in%fruits[f]
    meanyears<-ceiling(mean(x2[fruitsel,"Years"],na.rm=T))
    ntrees<-ntreesmat[f,1]
    prodmonths<-Data2[f,"MonthsProdYear"]
    
    for(y in 1:30){
      ynyear01<-ifelse(y<meanyears,0,1)
      ynyear01Cocona<-ifelse((y-meanyears)%in%c(0,1,2),1,0)
      ynyear01Araza<-ifelse(y<meanyears,0,1)
      
      establishmentcost<-ifelse(y==1,10000,0)
      
      if(f%in%c(5)){costseedlings<-0}
      if(f%in%c(1:4,6:10)){costseedlings<-ifelse(y==1,ntrees*3,ifelse(y==2,ntrees*0.15*3,ifelse(y==3,ntrees*0.05*3,ntrees*0.005*3)))}
      
      if(f%in%c(1,2,4,6:10)){costharvest<-ynyear01*4*prodmonths*50}
      if(f%in%c(3)){costharvest<-ynyear01Araza*4*prodmonths*50}
      if(f%in%c(5)){costharvest<-ynyear01Cocona*4*prodmonths*50}
      
      transportcost<-200*12
      
      timeveccost[y,f]<-(establishmentcost/10)+costharvest+costseedlings+(transportcost/10)
    }  
  }
  return(rowSums(timeveccost))
}

#bootstrap
b2costrandom=boot(Data1,costfrandom,R=10000)
b2costrandom$t0

#make plotable data frame from bootstrap result
allcostrandom<-matrix(NA,30,3)
colnames(allcostrandom)<-c("mean","min","max")
allcostrandom[,1]<-b2costrandom$t0
for(i in 1:30){
  allcostrandom[i,2]<-quantile(b2costrandom$t[,i],0.025,na.rm=T)
  allcostrandom[i,3]<-quantile(b2costrandom$t[,i],0.975,na.rm=T)
}
allcostrandom<-as.data.frame(allcostrandom)
allcostrandom[,"time"]<-c(1:30)

quantile(b2costrandom$t[,1],0.025,na.rm=T)
quantile(b2costrandom$t[,30],na.rm=T)

#ggplot
pcostrandom<-ggplot(allcostrandom,aes(x=time,y=mean))+
  geom_ribbon(fill = "blue",alpha=0.5,aes(x=time,ymin=min,ymax=max))+
  geom_line()+
  labs(y="Costs (PEN/4ha/y)", x="Time (y)")
pcostrandom

#### Profit

#create function combining revenues and profit
profitfrandom<-function(x,d){
  ##Determine frequencies
  
  #shade givers (n=5)
  sg1<-sample(c(1:400),1)
  sg2<-ifelse(sg1==400,0,sample(c(1:(400-sg1)),1))
  sg3<-ifelse((sg1+sg2)==400,0,sample(c(1:(400-(sg1+sg2))),1))
  sg4<-ifelse((sg1+sg2+sg3)==400,0,sample(c(1:(400-(sg1+sg2+sg3))),1))
  sg5<-ifelse((sg1+sg2+sg3+sg4)==400,0,400-(sg1+sg2+sg3))
  ntreesguaba<-sg1
  ntreeshuasai<-sg2
  ntreesaguaje<-sg3
  ntreespijuayo<-sg4
  ntreesungurahui<-sg5
  
  #shade tolerant (n=2)
  st1<-sample(c(1:400),1)
  st2<-ifelse(st1==400,0,400-st1)
  ntreesaraza<-st1
  ntreescopoazu<-st2
  
  #light demanding (n=2)
  ld1<-sample(c(1:400),1)
  ld2<-ifelse(ld1==400,0,400-ld1)
  ntreescamucamu<-ld1
  ntreesguanabana<-ld2
  
  #cocona
  ntreescocona<-800
  
  ntreesmat<-matrix(NA,10,1)
  ntreesmat[1,1]<-ntreeshuasai
  ntreesmat[2,1]<-ntreesaguaje
  ntreesmat[3,1]<-ntreesaraza
  ntreesmat[4,1]<-ntreescamucamu
  ntreesmat[5,1]<-ntreescocona
  ntreesmat[6,1]<-ntreescopoazu
  ntreesmat[7,1]<-ntreesguaba
  ntreesmat[8,1]<-ntreesguanabana
  ntreesmat[9,1]<-ntreespijuayo
  ntreesmat[10,1]<-ntreesungurahui
  
  timevec<-matrix(NA,30,10)
  timevecn<-matrix(NA,30,10)
  x2<-x[d,]
  for(f in 1:10){
    fruitsel<-x2[,"Fruit"]%in%fruits[f]
    meanyears<-ceiling(mean(x2[fruitsel,"Years"],na.rm=T))
    meanprod<-mean(x2[fruitsel,"Prod"],na.rm=T)
    meanprice<-mean(x2[fruitsel,"Price"],na.rm=T)
    for(y in 1:30){
      ynyear<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/4),ifelse((y-meanyears)==1,(2/4),ifelse((y-meanyears)==2,3/4,1))))
      ynyearCocona<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/2),ifelse((y-meanyears)==1,1,ifelse((y-meanyears)==2,1/2,0)))) 
      ynyearAraza<-ifelse(y<meanyears,0,ifelse((y-meanyears)==0,(1/4),ifelse((y-meanyears)==1,(2/4),ifelse((y-meanyears)==2,3/4,ifelse((y-meanyears)==3,1,ifelse((y-meanyears)==4,3/4,1/2))))))
      if(f%in%c(1,2,4,6:10)){timevec[y,f]<-0.9*ynyear*meanprod*meanprice}
      if(f%in%c(3)){timevec[y,f]<-0.9*ynyearAraza*meanprod*meanprice}
      if(f%in%c(5)){timevec[y,f]<-0.9*ynyearCocona*meanprod*meanprice}
      timevecn[y,f]<-timevec[y,f]*ntreesmat[f,1]
      
      
    }}  
  timeveccost<-matrix(NA,30,10)
  timeveccostn<-matrix(NA,30,10)
  for(f in 1:10){
    fruitsel<-x2[,"Fruit"]%in%fruits[f]
    meanyears<-ceiling(mean(x2[fruitsel,"Years"],na.rm=T))
    ntrees<-ntreesmat[f,1]
    prodmonths<-Data2[f,"MonthsProdYear"]
    
    for(y in 1:30){
      ynyear01<-ifelse(y<meanyears,0,1)
      ynyear01Cocona<-ifelse((y-meanyears)%in%c(0,1,2),1,0)
      ynyear01Araza<-ifelse(y<meanyears,0,1)
      
      establishmentcost<-ifelse(y==1,10000,0)
      
      if(f%in%c(5)){costseedlings<-0}
      if(f%in%c(1:4,6:10)){costseedlings<-ifelse(y==1,ntrees*3,ifelse(y==2,ntrees*0.15*3,ifelse(y==3,ntrees*0.05*3,ntrees*0.005*3)))}
      
      if(f%in%c(1,2,4,6:10)){costharvest<-ynyear01*4*prodmonths*50}
      if(f%in%c(3)){costharvest<-ynyear01Araza*4*prodmonths*50}
      if(f%in%c(5)){costharvest<-ynyear01Cocona*4*prodmonths*50}
      
      transportcost<-200*12
      
      timeveccost[y,f]<-(establishmentcost/10)+costharvest+costseedlings+(transportcost/10)
      
    }}
  return(rowSums(timevecn)-rowSums(timeveccost))
}

#bootstrap profit function
b2randomprofit=boot(Data1,profitfrandom,R=10000)
b2randomprofit$t0

#make plotable data frame from bootstrap result
allprofitrandom<-matrix(NA,30,3)
colnames(allprofitrandom)<-c("mean","min","max")
allprofitrandom[,1]<-b2randomprofit$t0
for(y in 1:30){
  allprofitrandom[y,2]<-quantile(b2randomprofit$t[,y],0.025,na.rm=T)
  allprofitrandom[y,3]<-quantile(b2randomprofit$t[,y],0.975,na.rm=T)
}

#ggplot profit
allprofitrandom<-as.data.frame(allprofitrandom)
allprofitrandom[,"time"]<-c(1:30)
head(allprofitrandom)
pprofitrandom<-ggplot(allprofitrandom,aes(x=time,y=mean))+
  geom_ribbon(fill = "palevioletred3",alpha=0.5,aes(x=time,ymin=min,ymax=max))+
  geom_line()+
  labs(y="Revenue (PEN/4ha/y)", x="Time (y)")
pprofitrandom

#### Combined PLOT
grid.arrange(prevrandom,pcostrandom,pprofitrandom, nrow = 1)





